submit

Macro submit 

submit!() { /* proc-macro */ }
Submit an answer for the given part: submit!(part, answer).

This must be used within a function annotated with #[aocd(year, day)].

If you provide a file name in the function annotation, this just prints the answer without submitting it to Advent of Code.